pub struct PipeReader { /* private fields */ }Expand description
The reading end of a pipe.
Implementations
Sourceimpl PipeReader
impl PipeReader
Sourcepub fn set_nonblocking(&mut self, nonblocking: bool)
pub fn set_nonblocking(&mut self, nonblocking: bool)
Set the non-blocking mode for this end of the pipe.
If non-blocking mode is enabled, attempting to read from an empty pipe will return an WouldBlock error instead
of blocking the current thread until data becomes available.